package net.buildbox.sample.likesiri2;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import android.content.ContentValues;
import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class LogDBHelper extends SQLiteOpenHelper {
	private static LogDBHelper instance = null;
	
	private static final String DB_NAME = "likesiri2.db";	// DB名
	private static final int    DB_VERSION = 1;				// バージョン
	public static final String DB_TABLE = "tblog";			// テーブル名
	
	public static final String[] LOG_PROJECTION = new String[] {
		"_id",
		"log",
		"type",
		"date"
	};
	
	public static LogDBHelper getInstance(Context context) {
		if (instance == null) {
			instance = new LogDBHelper(context);
		}
		
		return instance;
	}
	
	public LogDBHelper(Context context) {
		super(context, DB_NAME, null, DB_VERSION);
	}
	
	@Override
	public void onCreate(SQLiteDatabase db) {
		// テーブルの生成
		db.execSQL("create table if not exists "
				+ DB_TABLE
				+ "(_id integer primary key autoincrement, "
				+ "log text, "
				+ "type integer, "
				+ "date text)");
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		// テーブルの再生成処理を行うようにしています
		db.execSQL("drop table if exists " + DB_TABLE);
		onCreate(db);
	}
	
	public static final int TYPE_START_UNKNOWN = 0;
	public static final int TYPE_START_TEL     = 1;
	public static final int TYPE_START_MAP     = 2;
	public static final int TYPE_TEL           = 3;
	public static final int TYPE_MAP           = 4;
	public void insertEventLog(int eventType, String log) {
		// 書き込み可能なデータベースの取得
		SQLiteDatabase db = getWritableDatabase();
		
		// ContentValuesに書き込むデータをセット
		ContentValues values = new ContentValues();	
		values.put("log", log);
		values.put("type", eventType);
		// 日時の情報は、フォーマットを変換後格納
		Date date = new Date();
		SimpleDateFormat format = new SimpleDateFormat("yyyy/MM/dd, kk:mm:ss", Locale.JAPAN);
		values.put("date", format.format(date));
		
		// テーブルに挿入
		db.insert(DB_TABLE, null, values);
	}
}
