package net.buildbox.sample.likesiri2;


import java.util.ArrayList;

import android.net.Uri;
import android.os.Bundle;
import android.content.ActivityNotFoundException;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.res.Resources;
import android.database.Cursor;
import android.speech.RecognizerIntent;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.LoaderManager;
import android.support.v4.content.Loader;
import android.support.v4.widget.SimpleCursorAdapter;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ListView;
import android.widget.Toast;

public class MainActivity extends FragmentActivity 
		implements LoaderManager.LoaderCallbacks<Cursor> {
	private static final int REQCODE_START = 100;	// 初期キー
	private static final int REQCODE_TEL   = 200;	// 電話
	private static final int REQCODE_MAP   = 300;	// 地図
	
	private SimpleCursorAdapter mAdapter = null;
	private String KEY_UI = "key_ui";	// プリファレンス用キー

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		// プリファレンスの取得
		SharedPreferences prefs = getPreferences(Context.MODE_PRIVATE);
		if (!prefs.getBoolean(KEY_UI, false)) {
			// 新UIの設定
			setContentView(R.layout.activity_main2);
		} else {
			// 旧UIの設定
			setContentView(R.layout.activity_main);
		}
		
		// リストビューの設定
		mAdapter = new SimpleCursorAdapter(this,
				android.R.layout.simple_list_item_2,
				null,
				new String[] {"log", "date"},
				new int[] {android.R.id.text1, android.R.id.text2}, 0);
		ListView lvLog = (ListView) findViewById(R.id.lvLog);
		lvLog.setAdapter(mAdapter);
		
		// Loaderの初期化
		getSupportLoaderManager().initLoader(0, null, this);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		if(item.getItemId() == R.id.action_ui) {
			SharedPreferences prefs = getPreferences(Context.MODE_PRIVATE);
			SharedPreferences.Editor editor = prefs.edit(); 
			if (!prefs.getBoolean(KEY_UI, false)) {
				editor.putBoolean(KEY_UI, true);
				editor.commit();
			} else {
				editor.putBoolean(KEY_UI, false);
				editor.commit();
			}
			
			// Activityの再起動
			finish();
			startActivity(new Intent(this, MainActivity.class));
			
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	// 音声入力画面を呼び出すIntentの発行
	public void sendSpeechIntent(int reqCode, String prompt) {
        try {
            // インテント作成
            Intent intent = new Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH);
            intent.putExtra(
                    RecognizerIntent.EXTRA_LANGUAGE_MODEL,
                    RecognizerIntent.LANGUAGE_MODEL_FREE_FORM);
            intent.putExtra(
                    RecognizerIntent.EXTRA_PROMPT,
                    prompt);	// 音声入力時に表示するテキスト
            
            // インテント発行
            startActivityForResult(intent, reqCode);
        } catch (ActivityNotFoundException e) {
            // このインテントに応答できるアクティビティがインストールされていない場合
            Toast.makeText(this,
                "ActivityNotFoundException", Toast.LENGTH_SHORT).show();
        }
	}

	// ボタンが押された時に呼び出される
	public void onClickEvent(View v) {
		String msg_start = getResources().getString(R.string.msg_start);
		sendSpeechIntent(REQCODE_START, msg_start);
	}
	
    // アクティビティ終了時に呼び出される
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
    	Intent requestIntent = null;
    	ArrayList<String> result = null;
    	Resources res = getResources();		// 文字列リソース取得用
    	
    	if (data == null) {
    		// 結果が取得できなかった
    		Toast.makeText(this, R.string.msg_unknown, Toast.LENGTH_SHORT).show();
    		return;
    	} else if (data != null) {
        	// 結果を文字列リストで取得
    		result = data.getStringArrayListExtra(
    				RecognizerIntent.EXTRA_RESULTS);
    	}
    	
    	// 要件の音声認識結果処理
        if (requestCode == REQCODE_START && resultCode == RESULT_OK) {
        	// キーワードが含まれているかどうかを判定し、処理を分岐
        	String keyTel = getResources().getString(R.string.key_tel);	// キーワード（電話）
        	String keyMap = getResources().getString(R.string.key_map);	// キーワード（地図）
        	if (result.get(0).indexOf(keyTel) != -1) {
        		// 電話
        		String msgTel = res.getString(R.string.msg_tel);
        		sendSpeechIntent(REQCODE_TEL, msgTel);
        		
        		// 電話入力モード切替のログ書き込み
        		LogDBHelper logHelper = LogDBHelper.getInstance(this);
        		logHelper.insertEventLog(LogDBHelper.TYPE_START_TEL, "電話入力モードに移ります。\n**電話番号入力モード**");
        		getSupportLoaderManager().restartLoader(0, null, this);
        	} else if (result.get(0).indexOf(keyMap) != -1) {
        		// 地図
        		String msgMap = res.getString(R.string.msg_map);
        		sendSpeechIntent(REQCODE_MAP, msgMap);
        		
        		// 地図表示モード切替のログ書き込み
        		LogDBHelper logHelper = LogDBHelper.getInstance(this);
        		logHelper.insertEventLog(LogDBHelper.TYPE_START_MAP, "地図表示モードに移ります。\n**地図表示モード**");
        		getSupportLoaderManager().restartLoader(0, null, this);
        	} else {
        		// 不明
        		Toast.makeText(this, R.string.msg_unknown, Toast.LENGTH_SHORT).show();
        		
        		// 不明時のログ書き込み
        		LogDBHelper logHelper = LogDBHelper.getInstance(this);
        		logHelper.insertEventLog(LogDBHelper.TYPE_START_UNKNOWN, "認識ができませんでした。\n**再度しゃべってください。**");
        		getSupportLoaderManager().restartLoader(0, null, this);
        	}
        // 電話番号の音声認識結果処理
        } else if (requestCode == REQCODE_TEL && resultCode == RESULT_OK) {
        	requestIntent = new Intent(Intent.ACTION_VIEW, Uri.parse("tel:" + result.get(0)));
        	startActivity(requestIntent);
        	
    		// 電話呼び出しのログ書き込み
    		LogDBHelper logHelper = LogDBHelper.getInstance(this);
    		logHelper.insertEventLog(LogDBHelper.TYPE_TEL, "電話番号をかけます。\n**電話モード: " + result.get(0) + " **");
    		getSupportLoaderManager().restartLoader(0, null, this);
        // 地図検索の音声認識結果処理
        } else if (requestCode == REQCODE_MAP && resultCode == RESULT_OK) {
        	requestIntent = new Intent(Intent.ACTION_VIEW, Uri.parse("geo:0,0?q=" + result.get(0)));
        	startActivity(requestIntent);
        	
        	// 地図呼び出しのログ書き込み
    		LogDBHelper logHelper = LogDBHelper.getInstance(this);
    		logHelper.insertEventLog(LogDBHelper.TYPE_MAP, "地図を表示します。\n**電話モード: " + result.get(0) + " **");
    		getSupportLoaderManager().restartLoader(0, null, this);
        }
        
        super.onActivityResult(requestCode, resultCode, data);
    }

	@Override
	public Loader<Cursor> onCreateLoader(int id, Bundle args) {
		return new LogCursorLoader(this);
	}

	@Override
	public void onLoadFinished(Loader<Cursor> loader, Cursor cursor) {
		// 読み込んだCursorインスタンスを設定
		mAdapter.swapCursor(cursor);
	}

	@Override
	public void onLoaderReset(Loader<Cursor> loader) {
		// リストビューに空を設定
		mAdapter.swapCursor(null);
	}
}
